@@ -204,6 +204,13 @@ class DHKEM_P256_HKDF_SHA256(_DHKEMWeierstrass):
     ID = 0x0010
 
 
+class DHKEM_P384_HKDF_SHA384(_DHKEMWeierstrass):
+    CURVE = ec.SECP384R1()
+    KDF = HKDF_SHA384
+    NSECRET = 32
+    ID = 0x0010
+
+
 class DHKEM_P521_HKDF_SHA512(_DHKEMWeierstrass):
     CURVE = ec.SECP521R1()
     KDF = HKDF_SHA512
@@ -571,23 +578,13 @@ class Suite__DHKEM_P256_HKDF_SHA256__HKDF_SHA256__AES_128_GCM(_Suite):
     AEAD = _AES_128_GCM
 
 
-class Suite__DHKEM_P256_HKDF_SHA256__HKDF_SHA512__AES_128_GCM(_Suite):
+class Suite__DHKEM_P256_HKDF_SHA256__HKDF_SHA256__AES_256_GCM(_Suite):
     """
-    This is DHKEM(P-256, HKDF-SHA256), HKDF-SHA512, AES-128-GCM
+    This is DHKEM(P-256, HKDF-SHA256), HKDF-SHA256, AES-256-GCM
     """
 
     KEM = DHKEM_P256_HKDF_SHA256
-    KDF = HKDF_SHA512
-    AEAD = _AES_128_GCM
-
-
-class Suite__DHKEM_P521_HKDF_SHA512__HKDF_SHA512__AES_256_GCM(_Suite):
-    """
-    This is DHKEM(P-521, HKDF-SHA512), HKDF-SHA512, AES-256-GCM
-    """
-
-    KEM = DHKEM_P521_HKDF_SHA512
-    KDF = HKDF_SHA512
+    KDF = HKDF_SHA256
     AEAD = _AES_256_GCM
 
 
@@ -611,6 +608,76 @@ class Suite__DHKEM_P256_HKDF_SHA256__HKDF_SHA256__ExportOnly(_Suite):
     AEAD = _ExportOnlyAEAD
 
 
+class Suite__DHKEM_P256_HKDF_SHA256__HKDF_SHA384__AES_128_GCM(_Suite):
+    """
+    This is DHKEM(P-256, HKDF-SHA256), HKDF-SHA384, AES-128-GCM
+    """
+
+    KEM = DHKEM_P256_HKDF_SHA256
+    KDF = HKDF_SHA384
+    AEAD = _AES_128_GCM
+
+
+class Suite__DHKEM_P256_HKDF_SHA256__HKDF_SHA384__AES_256_GCM(_Suite):
+    """
+    This is DHKEM(P-256, HKDF-SHA256), HKDF-SHA384, AES-256-GCM
+    """
+
+    KEM = DHKEM_P256_HKDF_SHA256
+    KDF = HKDF_SHA384
+    AEAD = _AES_256_GCM
+
+
+class Suite__DHKEM_P256_HKDF_SHA256__HKDF_SHA384__ChaCha20Poly1305(_Suite):
+    """
+    This is DHKEM(P-256, HKDF-SHA256), HKDF-SHA384, ChaCha20Poly1305
+    """
+
+    KEM = DHKEM_P256_HKDF_SHA256
+    KDF = HKDF_SHA384
+    AEAD = _ChaCha20Poly1305
+
+
+class Suite__DHKEM_P256_HKDF_SHA256__HKDF_SHA384__ExportOnly(_Suite):
+    """
+    This is DHKEM(P-256, HKDF-SHA256), HKDF-SHA384, ExportOnly
+    """
+
+    KEM = DHKEM_P256_HKDF_SHA256
+    KDF = HKDF_SHA384
+    AEAD = _ExportOnlyAEAD
+
+
+class Suite__DHKEM_P256_HKDF_SHA256__HKDF_SHA512__AES_128_GCM(_Suite):
+    """
+    This is DHKEM(P-256, HKDF-SHA256), HKDF-SHA512, AES-128-GCM
+    """
+
+    KEM = DHKEM_P256_HKDF_SHA256
+    KDF = HKDF_SHA512
+    AEAD = _AES_128_GCM
+
+
+class Suite__DHKEM_P256_HKDF_SHA256__HKDF_SHA512__AES_256_GCM(_Suite):
+    """
+    This is DHKEM(P-256, HKDF-SHA256), HKDF-SHA512, AES-256-GCM
+    """
+
+    KEM = DHKEM_P256_HKDF_SHA256
+    KDF = HKDF_SHA512
+    AEAD = _AES_256_GCM
+
+
+class Suite__DHKEM_P256_HKDF_SHA256__HKDF_SHA512__ChaCha20Poly1305(_Suite):
+    """
+    This is DHKEM(P-256, HKDF-SHA256), HKDF-SHA512, ChaCha20Poly1305
+    """
+
+    KEM = DHKEM_P256_HKDF_SHA256
+    KDF = HKDF_SHA512
+    AEAD = _ChaCha20Poly1305
+
+
 class Suite__DHKEM_P256_HKDF_SHA256__HKDF_SHA512__ExportOnly(_Suite):
     """
     This is DHKEM(P-256, HKDF-SHA256), HKDF-SHA512, ExportOnly
@@ -619,3 +686,243 @@ class Suite__DHKEM_P256_HKDF_SHA256__HKDF_SHA512__ExportOnly(_Suite):
     KEM = DHKEM_P256_HKDF_SHA256
     KDF = HKDF_SHA512
     AEAD = _ExportOnlyAEAD
+
+
+class Suite__DHKEM_P384_HKDF_SHA384__HKDF_SHA256__AES_128_GCM(_Suite):
+    """
+    This is DHKEM(P-384, HKDF-SHA384), HKDF-SHA256, AES-128-GCM
+    """
+
+    KEM = DHKEM_P384_HKDF_SHA384
+    KDF = HKDF_SHA256
+    AEAD = _AES_128_GCM
+
+
+class Suite__DHKEM_P384_HKDF_SHA384__HKDF_SHA256__AES_256_GCM(_Suite):
+    """
+    This is DHKEM(P-384, HKDF-SHA384), HKDF-SHA256, AES-256-GCM
+    """
+
+    KEM = DHKEM_P384_HKDF_SHA384
+    KDF = HKDF_SHA256
+    AEAD = _AES_256_GCM
+
+
+class Suite__DHKEM_P384_HKDF_SHA384__HKDF_SHA256__ChaCha20Poly1305(_Suite):
+    """
+    This is DHKEM(P-384, HKDF-SHA384), HKDF-SHA256, ChaCha20Poly1305
+    """
+
+    KEM = DHKEM_P384_HKDF_SHA384
+    KDF = HKDF_SHA256
+    AEAD = _ChaCha20Poly1305
+
+
+class Suite__DHKEM_P384_HKDF_SHA384__HKDF_SHA256__ExportOnly(_Suite):
+    """
+    This is DHKEM(P-384, HKDF-SHA384), HKDF-SHA256, ExportOnly
+    """
+
+    KEM = DHKEM_P384_HKDF_SHA384
+    KDF = HKDF_SHA256
+    AEAD = _ExportOnlyAEAD
+
+
+class Suite__DHKEM_P384_HKDF_SHA384__HKDF_SHA384__AES_128_GCM(_Suite):
+    """
+    This is DHKEM(P-384, HKDF-SHA384), HKDF-SHA384, AES-128-GCM
+    """
+
+    KEM = DHKEM_P384_HKDF_SHA384
+    KDF = HKDF_SHA384
+    AEAD = _AES_128_GCM
+
+
+class Suite__DHKEM_P384_HKDF_SHA384__HKDF_SHA384__AES_256_GCM(_Suite):
+    """
+    This is DHKEM(P-384, HKDF-SHA384), HKDF-SHA384, AES-256-GCM
+    """
+
+    KEM = DHKEM_P384_HKDF_SHA384
+    KDF = HKDF_SHA384
+    AEAD = _AES_256_GCM
+
+
+class Suite__DHKEM_P384_HKDF_SHA384__HKDF_SHA384__ChaCha20Poly1305(_Suite):
+    """
+    This is DHKEM(P-384, HKDF-SHA384), HKDF-SHA384, ChaCha20Poly1305
+    """
+
+    KEM = DHKEM_P384_HKDF_SHA384
+    KDF = HKDF_SHA384
+    AEAD = _ChaCha20Poly1305
+
+
+class Suite__DHKEM_P384_HKDF_SHA384__HKDF_SHA384__ExportOnly(_Suite):
+    """
+    This is DHKEM(P-384, HKDF-SHA384), HKDF-SHA384, ExportOnly
+    """
+
+    KEM = DHKEM_P384_HKDF_SHA384
+    KDF = HKDF_SHA384
+    AEAD = _ExportOnlyAEAD
+
+
+class Suite__DHKEM_P384_HKDF_SHA384__HKDF_SHA512__AES_128_GCM(_Suite):
+    """
+    This is DHKEM(P-384, HKDF-SHA384), HKDF-SHA512, AES-128-GCM
+    """
+
+    KEM = DHKEM_P384_HKDF_SHA384
+    KDF = HKDF_SHA512
+    AEAD = _AES_128_GCM
+
+
+class Suite__DHKEM_P384_HKDF_SHA384__HKDF_SHA512__AES_256_GCM(_Suite):
+    """
+    This is DHKEM(P-384, HKDF-SHA384), HKDF-SHA512, AES-256-GCM
+    """
+
+    KEM = DHKEM_P384_HKDF_SHA384
+    KDF = HKDF_SHA512
+    AEAD = _AES_256_GCM
+
+
+class Suite__DHKEM_P384_HKDF_SHA384__HKDF_SHA512__ChaCha20Poly1305(_Suite):
+    """
+    This is DHKEM(P-384, HKDF-SHA384), HKDF-SHA512, ChaCha20Poly1305
+    """
+
+    KEM = DHKEM_P384_HKDF_SHA384
+    KDF = HKDF_SHA512
+    AEAD = _ChaCha20Poly1305
+
+
+class Suite__DHKEM_P384_HKDF_SHA384__HKDF_SHA512__ExportOnly(_Suite):
+    """
+    This is DHKEM(P-384, HKDF-SHA384), HKDF-SHA512, ExportOnly
+    """
+
+    KEM = DHKEM_P384_HKDF_SHA384
+    KDF = HKDF_SHA512
+    AEAD = _ExportOnlyAEAD
+
+
+class Suite__DHKEM_P521_HKDF_SHA512__HKDF_SHA256__AES_128_GCM(_Suite):
+    """
+    This is DHKEM(P-521, HKDF-SHA512), HKDF-SHA256, AES-128-GCM
+    """
+
+    KEM = DHKEM_P521_HKDF_SHA512
+    KDF = HKDF_SHA256
+    AEAD = _AES_128_GCM
+
+
+class Suite__DHKEM_P521_HKDF_SHA512__HKDF_SHA256__AES_256_GCM(_Suite):
+    """
+    This is DHKEM(P-521, HKDF-SHA512), HKDF-SHA256, AES-256-GCM
+    """
+
+    KEM = DHKEM_P521_HKDF_SHA512
+    KDF = HKDF_SHA256
+    AEAD = _AES_256_GCM
+
+
+class Suite__DHKEM_P521_HKDF_SHA512__HKDF_SHA256__ChaCha20Poly1305(_Suite):
+    """
+    This is DHKEM(P-521, HKDF-SHA512), HKDF-SHA256, ChaCha20Poly1305
+    """
+
+    KEM = DHKEM_P521_HKDF_SHA512
+    KDF = HKDF_SHA256
+    AEAD = _ChaCha20Poly1305
+
+
+class Suite__DHKEM_P521_HKDF_SHA512__HKDF_SHA256__ExportOnly(_Suite):
+    """
+    This is DHKEM(P-521, HKDF-SHA512), HKDF-SHA256, ExportOnly
+    """
+
+    KEM = DHKEM_P521_HKDF_SHA512
+    KDF = HKDF_SHA256
+    AEAD = _ExportOnlyAEAD
+
+
+class Suite__DHKEM_P521_HKDF_SHA512__HKDF_SHA384__AES_128_GCM(_Suite):
+    """
+    This is DHKEM(P-521, HKDF-SHA512), HKDF-SHA384, AES-128-GCM
+    """
+
+    KEM = DHKEM_P521_HKDF_SHA512
+    KDF = HKDF_SHA384
+    AEAD = _AES_128_GCM
+
+
+class Suite__DHKEM_P521_HKDF_SHA512__HKDF_SHA384__AES_256_GCM(_Suite):
+    """
+    This is DHKEM(P-521, HKDF-SHA512), HKDF-SHA384, AES-256-GCM
+    """
+
+    KEM = DHKEM_P521_HKDF_SHA512
+    KDF = HKDF_SHA384
+    AEAD = _AES_256_GCM
+
+
+class Suite__DHKEM_P521_HKDF_SHA512__HKDF_SHA384__ChaCha20Poly1305(_Suite):
+    """
+    This is DHKEM(P-521, HKDF-SHA512), HKDF-SHA384, ChaCha20Poly1305
+    """
+
+    KEM = DHKEM_P521_HKDF_SHA512
+    KDF = HKDF_SHA384
+    AEAD = _ChaCha20Poly1305
+
+
+class Suite__DHKEM_P521_HKDF_SHA512__HKDF_SHA384__ExportOnly(_Suite):
+    """
+    This is DHKEM(P-521, HKDF-SHA512), HKDF-SHA384, ExportOnly
+    """
+
+    KEM = DHKEM_P521_HKDF_SHA512
+    KDF = HKDF_SHA384
+    AEAD = _ExportOnlyAEAD
+
+
+class Suite__DHKEM_P521_HKDF_SHA512__HKDF_SHA512__AES_128_GCM(_Suite):
+    """
+    This is DHKEM(P-521, HKDF-SHA512), HKDF-SHA512, AES-128-GCM
+    """
+
+    KEM = DHKEM_P521_HKDF_SHA512
+    KDF = HKDF_SHA512
+    AEAD = _AES_128_GCM
+
+
+class Suite__DHKEM_P521_HKDF_SHA512__HKDF_SHA512__AES_256_GCM(_Suite):
+    """
+    This is DHKEM(P-521, HKDF-SHA512), HKDF-SHA512, AES-256-GCM
+    """
+
+    KEM = DHKEM_P521_HKDF_SHA512
+    KDF = HKDF_SHA512
+    AEAD = _AES_256_GCM
+
+
+class Suite__DHKEM_P521_HKDF_SHA512__HKDF_SHA512__ChaCha20Poly1305(_Suite):
+    """
+    This is DHKEM(P-521, HKDF-SHA512), HKDF-SHA512, ChaCha20Poly1305
+    """
+
+    KEM = DHKEM_P521_HKDF_SHA512
+    KDF = HKDF_SHA512
+    AEAD = _ChaCha20Poly1305
+
+
+class Suite__DHKEM_P521_HKDF_SHA512__HKDF_SHA512__ExportOnly(_Suite):
+    """
+    This is DHKEM(P-521, HKDF-SHA512), HKDF-SHA512, ExportOnly
+    """
+
+    KEM = DHKEM_P521_HKDF_SHA512
+    KDF = HKDF_SHA512
+    AEAD = _ExportOnlyAEAD
